Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(656)

Unified Diff: sdk/lib/mirrors/mirrors.dart

Issue 23890036: Change return type of get typeVariables and typeArguments in ClassMirror. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/mirrors/mirrors.dart
diff --git a/sdk/lib/mirrors/mirrors.dart b/sdk/lib/mirrors/mirrors.dart
index 313026f26ee74379a00199a0e78258661820fd51..12adcda87411c5a370f57c24ee6864dbbaeafbe7 100644
--- a/sdk/lib/mirrors/mirrors.dart
+++ b/sdk/lib/mirrors/mirrors.dart
@@ -748,32 +748,30 @@ abstract class ClassMirror implements TypeMirror, ObjectMirror {
Map<Symbol, MethodMirror> get constructors;
/**
- * An immutable map from names to mirrors for all type variables for
- * this type.
- * If this type is a generic declaration or an invocation of
- * a generic declaration, the returned map has the names of the formal
- * type parameters of the original declaration as its keys, and
- * each such key maps to a TypeVariableMirror on the corresponding
- * type variable. Otherwise, the returned map is empty.
+ * A list with mirrors for all type variables for this type.
ahe 2013/09/18 15:08:27 an immutable list
zarah 2013/09/19 07:00:24 Done.
+ *
+ * If this type is a generic declaration or an invocation of a generic
+ * declaration, the returned list contains mirrors on the type variables.
+ * Otherwise, the returned list is empty.
*
* This map preserves the order of declaration of the type variables.
*/
- Map<Symbol, TypeVariableMirror> get typeVariables;
+ List<TypeVariableMirror> get typeVariables;
/**
- * An immutable map from names to mirrors for all type arguments for
- * this type. The keys of the map are the names of the
- * corresponding type variables.
+ * A list with mirrors for all type arguments for
ahe 2013/09/18 15:08:27 an immutable list
zarah 2013/09/19 07:00:24 Done.
+ * this type.
*
* If the the reflectee is an invocation of a generic class,
* the type arguments are the bindings of its type parameters.
* If the reflectee is the original declaration of a generic,
* it has no type arguments and this method returns an empty map.
* If the reflectee is a not generic, then
* it has no type arguments and this method returns an empty map.
* This map preserves the order of declaration of the type variables.
*/
- Map<Symbol, TypeMirror> get typeArguments;
+ List<TypeVariableMirror> get typeArguments;
gbracha 2013/09/18 19:54:35 List<TypeMirror>
zarah 2013/09/19 07:00:24 Done.
/**
@@ -748,32 +748,30 @@ abstract class ClassMirror implements TypeMirror, ObjectMirror {
*
- * This map preserves the order of declaration of the type variables.
+ * This list preserves the order of declaration of the type variables.
*/
@@ -748,32 +748,30 @@ abstract class ClassMirror implements TypeMirror, ObjectMirror {
* the type arguments are the bindings of its type parameters.
* If the reflectee is the original declaration of a generic,
- * it has no type arguments and this method returns an empty map.
+ * it has no type arguments and this method returns an empty list.
* If the reflectee is a not generic, then
@@ -748,32 +748,30 @@ abstract class ClassMirror implements TypeMirror, ObjectMirror {
* If the reflectee is a not generic, then
- * it has no type arguments and this method returns an empty map.
- * This map preserves the order of declaration of the type variables.
+ * it has no type arguments and this method returns an empty list.
+ *
+ * This list preserves the order of declaration of the type variables.
*/
* Is this the original declaration of this type?

Powered by Google App Engine
This is Rietveld 408576698